@@ -128,10 +128,42 @@
  *   clang -D__API_TO_BE_DEPRECATED=11.0 <other compiler flags>
  */
  
-#ifndef __API_TO_BE_DEPRECATED
-#define __API_TO_BE_DEPRECATED 100000
+ #ifndef __API_TO_BE_DEPRECATED
+ #define __API_TO_BE_DEPRECATED 100000
+ #endif
+ 
+#ifndef __API_TO_BE_DEPRECATED_MACOS
+#define __API_TO_BE_DEPRECATED_MACOS 100000
 #endif
 
+#ifndef __API_TO_BE_DEPRECATED_IOS
+#define __API_TO_BE_DEPRECATED_IOS 100000
+#endif
+#ifndef __API_TO_BE_DEPRECATED_MACCATALYST
+#define __API_TO_BE_DEPRECATED_MACCATALYST 100000
+#endif
+
+#ifndef __API_TO_BE_DEPRECATED_WATCHOS
+#define __API_TO_BE_DEPRECATED_WATCHOS 100000
+#endif
+
+#ifndef __API_TO_BE_DEPRECATED_TVOS
+#define __API_TO_BE_DEPRECATED_TVOS 100000
+#endif
+
+#ifndef __API_TO_BE_DEPRECATED_BRIDGEOS
+
+#endif
+
+#ifndef __API_TO_BE_DEPRECATED_DRIVERKIT
+#define __API_TO_BE_DEPRECATED_DRIVERKIT 100000
+#endif
+
+#ifndef __API_TO_BE_DEPRECATED_XROS
+#define __API_TO_BE_DEPRECATED_XROS 100000
+#endif
+
+
 #include <AvailabilityVersions.h>
 #include <AvailabilityInternal.h>
 
@@ -250,11 +282,17 @@
 #endif
 
 
+#if __has_include(<AvailabilityProhibitedInternal.h>)
+  #include <AvailabilityProhibitedInternal.h>
+#endif
+
 /* for use marking APIs available info for iOS */
 #if defined(__has_attribute)
   #if __has_attribute(availability)
     #define __IOS_UNAVAILABLE                    __OS_AVAILABILITY(ios,unavailable)
-    #define __IOS_PROHIBITED                     __OS_AVAILABILITY(ios,unavailable)
+    #ifndef __IOS_PROHIBITED
+      #define __IOS_PROHIBITED                     __OS_AVAILABILITY(ios,unavailable)
+    #endif
     #define __IOS_AVAILABLE(_vers)               __OS_AVAILABILITY(ios,introduced=_vers)
     #define __IOS_DEPRECATED(_start, _dep, _msg) __IOS_AVAILABLE(_start) __OS_AVAILABILITY_MSG(ios,deprecated=_dep,_msg)
   #endif
@@ -281,7 +319,9 @@
 #if defined(__has_feature)
   #if __has_feature(attribute_availability_tvos)
     #define __TVOS_UNAVAILABLE                    __OS_AVAILABILITY(tvos,unavailable)
-    #define __TVOS_PROHIBITED                     __OS_AVAILABILITY(tvos,unavailable)
+    #ifndef __TVOS_PROHIBITED
+      #define __TVOS_PROHIBITED                     __OS_AVAILABILITY(tvos,unavailable)
+    #endif
     #define __TVOS_AVAILABLE(_vers)               __OS_AVAILABILITY(tvos,introduced=_vers)
     #define __TVOS_DEPRECATED(_start, _dep, _msg) __TVOS_AVAILABLE(_start) __OS_AVAILABILITY_MSG(tvos,deprecated=_dep,_msg)
   #endif
@@ -308,7 +348,9 @@
 #if defined(__has_feature)
   #if __has_feature(attribute_availability_watchos)
     #define __WATCHOS_UNAVAILABLE                    __OS_AVAILABILITY(watchos,unavailable)
-    #define __WATCHOS_PROHIBITED                     __OS_AVAILABILITY(watchos,unavailable)
+    #ifndef __WATCHOS_PROHIBITED
+      #define __WATCHOS_PROHIBITED                     __OS_AVAILABILITY(watchos,unavailable)
+    #endif
     #define __WATCHOS_AVAILABLE(_vers)               __OS_AVAILABILITY(watchos,introduced=_vers)
     #define __WATCHOS_DEPRECATED(_start, _dep, _msg) __WATCHOS_AVAILABLE(_start) __OS_AVAILABILITY_MSG(watchos,deprecated=_dep,_msg)
   #endif
@@ -330,7 +372,6 @@
   #define __WATCHOS_DEPRECATED(_start, _dep, _msg)
 #endif
 
-
 /* for use marking APIs unavailable for swift */
 #if defined(__has_feature)
   #if __has_feature(attribute_availability_swift)
@@ -378,9 +419,9 @@
      *    __API_AVAILABLE(macos(10.4), ios(8.0), watchos(2.0), tvos(10.0))
      *    __API_AVAILABLE(driverkit(19.0))
      */
-    #define __API_AVAILABLE(...) __API_AVAILABLE_GET_MACRO(__VA_ARGS__,__API_AVAILABLE7, __API_AVAILABLE6, __API_AVAILABLE5, __API_AVAILABLE4, __API_AVAILABLE3, __API_AVAILABLE2, __API_AVAILABLE1, 0)(__VA_ARGS__)
-    
-    #define __API_AVAILABLE_BEGIN(...) _Pragma("clang attribute push") __API_AVAILABLE_BEGIN_GET_MACRO(__VA_ARGS__,__API_AVAILABLE_BEGIN7, __API_AVAILABLE_BEGIN6, __API_AVAILABLE_BEGIN5, __API_AVAILABLE_BEGIN4, __API_AVAILABLE_BEGIN3, __API_AVAILABLE_BEGIN2, __API_AVAILABLE_BEGIN1, 0)(__VA_ARGS__)
+    #define __API_AVAILABLE(...) __API_AVAILABLE_GET_MACRO(__VA_ARGS__,__API_AVAILABLE7,__API_AVAILABLE6,__API_AVAILABLE5,__API_AVAILABLE4,__API_AVAILABLE3,__API_AVAILABLE2,__API_AVAILABLE1,__API_AVAILABLE0,0)(__VA_ARGS__)
+
+    #define __API_AVAILABLE_BEGIN(...) _Pragma("clang attribute push") __API_AVAILABLE_BEGIN_GET_MACRO(__VA_ARGS__,__API_AVAILABLE_BEGIN7,__API_AVAILABLE_BEGIN6,__API_AVAILABLE_BEGIN5,__API_AVAILABLE_BEGIN4,__API_AVAILABLE_BEGIN3,__API_AVAILABLE_BEGIN2,__API_AVAILABLE_BEGIN1,__API_AVAILABLE_BEGIN0,0)(__VA_ARGS__)
     #define __API_AVAILABLE_END _Pragma("clang attribute pop")
 
     /*
@@ -399,13 +440,13 @@
      *    __API_DEPRECATED_WITH_REPLACEMENT("-setName:", tvos(10.0, 10.4), ios(9.0, 10.0))
      *    __API_DEPRECATED_WITH_REPLACEMENT("SomeClassName", macos(10.4, 10.6), watchos(2.0, 3.0))
      */
-    #define __API_DEPRECATED(...) __API_DEPRECATED_MSG_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_MSG8,__API_DEPRECATED_MSG7,__API_DEPRECATED_MSG6,__API_DEPRECATED_MSG5,__API_DEPRECATED_MSG4,__API_DEPRECATED_MSG3,__API_DEPRECATED_MSG2,__API_DEPRECATED_MSG1, 0)(__VA_ARGS__)
-    #define __API_DEPRECATED_WITH_REPLACEMENT(...) __API_DEPRECATED_REP_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_REP8,__API_DEPRECATED_REP7,__API_DEPRECATED_REP6,__API_DEPRECATED_REP5,__API_DEPRECATED_REP4,__API_DEPRECATED_REP3,__API_DEPRECATED_REP2,__API_DEPRECATED_REP1, 0)(__VA_ARGS__)
+    #define __API_DEPRECATED(...) __API_DEPRECATED_MSG_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_MSG7,__API_DEPRECATED_MSG6,__API_DEPRECATED_MSG5,__API_DEPRECATED_MSG4,__API_DEPRECATED_MSG3,__API_DEPRECATED_MSG2,__API_DEPRECATED_MSG1,__API_DEPRECATED_MSG0,0,0)(__VA_ARGS__)
+    #define __API_DEPRECATED_WITH_REPLACEMENT(...) __API_DEPRECATED_REP_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_REP7,__API_DEPRECATED_REP6,__API_DEPRECATED_REP5,__API_DEPRECATED_REP4,__API_DEPRECATED_REP3,__API_DEPRECATED_REP2,__API_DEPRECATED_REP1,__API_DEPRECATED_REP0,0,0)(__VA_ARGS__)
 
-    #define __API_DEPRECATED_BEGIN(...) _Pragma("clang attribute push") __API_DEPRECATED_BEGIN_MSG_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_BEGIN_MSG8,__API_DEPRECATED_BEGIN_MSG7, __API_DEPRECATED_BEGIN_MSG6, __API_DEPRECATED_BEGIN_MSG5, __API_DEPRECATED_BEGIN_MSG4, __API_DEPRECATED_BEGIN_MSG3, __API_DEPRECATED_BEGIN_MSG2, __API_DEPRECATED_BEGIN_MSG1, 0)(__VA_ARGS__)
+    #define __API_DEPRECATED_BEGIN(...) _Pragma("clang attribute push") __API_DEPRECATED_BEGIN_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_BEGIN7,__API_DEPRECATED_BEGIN6,__API_DEPRECATED_BEGIN5,__API_DEPRECATED_BEGIN4,__API_DEPRECATED_BEGIN3,__API_DEPRECATED_BEGIN2,__API_DEPRECATED_BEGIN1,__API_DEPRECATED_BEGIN0,0,0)(__VA_ARGS__)
     #define __API_DEPRECATED_END _Pragma("clang attribute pop")
 
-    #define __API_DEPRECATED_WITH_REPLACEMENT_BEGIN(...) _Pragma("clang attribute push") __API_DEPRECATED_BEGIN_REP_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_BEGIN_REP8,__API_DEPRECATED_BEGIN_REP7, __API_DEPRECATED_BEGIN_REP6, __API_DEPRECATED_BEGIN_REP5, __API_DEPRECATED_BEGIN_REP4, __API_DEPRECATED_BEGIN_REP3, __API_DEPRECATED_BEGIN_REP2, __API_DEPRECATED_BEGIN_REP1, 0)(__VA_ARGS__)
+    #define __API_DEPRECATED_WITH_REPLACEMENT_BEGIN(...) _Pragma("clang attribute push") __API_DEPRECATED_WITH_REPLACEMENT_BEGIN_GET_MACRO(__VA_ARGS__,__API_DEPRECATED_WITH_REPLACEMENT_BEGIN7,__API_DEPRECATED_WITH_REPLACEMENT_BEGIN6,__API_DEPRECATED_WITH_REPLACEMENT_BEGIN5,__API_DEPRECATED_WITH_REPLACEMENT_BEGIN4,__API_DEPRECATED_WITH_REPLACEMENT_BEGIN3,__API_DEPRECATED_WITH_REPLACEMENT_BEGIN2,__API_DEPRECATED_WITH_REPLACEMENT_BEGIN1,__API_DEPRECATED_WITH_REPLACEMENT_BEGIN0,0,0)(__VA_ARGS__)
     #define __API_DEPRECATED_WITH_REPLACEMENT_END _Pragma("clang attribute pop")
 
     /*
@@ -416,51 +457,63 @@
      *    __API_UNAVAILABLE(macos)
      *    __API_UNAVAILABLE(watchos, tvos)
      */
-    #define __API_UNAVAILABLE(...) __API_UNAVAILABLE_GET_MACRO(__VA_ARGS__,__API_UNAVAILABLE7,__API_UNAVAILABLE6,__API_UNAVAILABLE5,__API_UNAVAILABLE4,__API_UNAVAILABLE3,__API_UNAVAILABLE2,__API_UNAVAILABLE1, 0)(__VA_ARGS__)
-
-    #define __API_UNAVAILABLE_BEGIN(...) _Pragma("clang attribute push") __API_UNAVAILABLE_BEGIN_GET_MACRO(__VA_ARGS__,__API_UNAVAILABLE_BEGIN7,__API_UNAVAILABLE_BEGIN6, __API_UNAVAILABLE_BEGIN5, __API_UNAVAILABLE_BEGIN4, __API_UNAVAILABLE_BEGIN3, __API_UNAVAILABLE_BEGIN2, __API_UNAVAILABLE_BEGIN1, 0)(__VA_ARGS__)
+    #define __API_UNAVAILABLE(...) __API_UNAVAILABLE_GET_MACRO(__VA_ARGS__,__API_UNAVAILABLE7,__API_UNAVAILABLE6,__API_UNAVAILABLE5,__API_UNAVAILABLE4,__API_UNAVAILABLE3,__API_UNAVAILABLE2,__API_UNAVAILABLE1,__API_UNAVAILABLE0,0)(__VA_ARGS__)
+  
+    #define __API_UNAVAILABLE_BEGIN(...) _Pragma("clang attribute push") __API_UNAVAILABLE_BEGIN_GET_MACRO(__VA_ARGS__,__API_UNAVAILABLE_BEGIN7,__API_UNAVAILABLE_BEGIN6,__API_UNAVAILABLE_BEGIN5,__API_UNAVAILABLE_BEGIN4,__API_UNAVAILABLE_BEGIN3,__API_UNAVAILABLE_BEGIN2,__API_UNAVAILABLE_BEGIN1,__API_UNAVAILABLE_BEGIN0,0)(__VA_ARGS__)
     #define __API_UNAVAILABLE_END _Pragma("clang attribute pop")
- #else 
-
-    /* 
-     * Evaluate to nothing for compilers that don't support availability.
-     */
-    
-    #define __API_AVAILABLE(...)
-    #define __API_AVAILABLE_BEGIN(...)
-    #define __API_AVAILABLE_END
-    #define __API_DEPRECATED(...)
-    #define __API_DEPRECATED_WITH_REPLACEMENT(...)
-    #define __API_DEPRECATED_BEGIN(...)
-    #define __API_DEPRECATED_END
-    #define __API_DEPRECATED_WITH_REPLACEMENT_BEGIN(...)
-    #define __API_DEPRECATED_WITH_REPLACEMENT_END
-    #define __API_UNAVAILABLE(...)
-    #define __API_UNAVAILABLE_BEGIN(...)
-    #define __API_UNAVAILABLE_END
  #endif /* __has_attribute(availability) */
-#else
-
-    /* 
-     * Evaluate to nothing for compilers that don't support clang language extensions.
-     */
-    
-    #define __API_AVAILABLE(...)
-    #define __API_AVAILABLE_BEGIN(...)
-    #define __API_AVAILABLE_END
-    #define __API_DEPRECATED(...)
-    #define __API_DEPRECATED_WITH_REPLACEMENT(...)
-    #define __API_DEPRECATED_BEGIN(...)
-    #define __API_DEPRECATED_END
-    #define __API_DEPRECATED_WITH_REPLACEMENT_BEGIN(...)
-    #define __API_DEPRECATED_WITH_REPLACEMENT_END
-    #define __API_UNAVAILABLE(...)
-    #define __API_UNAVAILABLE_BEGIN(...)
-    #define __API_UNAVAILABLE_END
 #endif /*  #if defined(__has_feature) && defined(__has_attribute) */
 
-#if __has_include(<AvailabilityProhibitedInternal.h>)
-  #include <AvailabilityProhibitedInternal.h>
+/* 
+ * Evaluate to nothing for compilers that don't support availability.
+ */
+
+#ifndef __API_AVAILABLE
+  #define __API_AVAILABLE(...)
+#endif
+
+#ifndef __API_AVAILABLE_BEGIN
+  #define __API_AVAILABLE_BEGIN(...)
+#endif
+
+#ifndef __API_AVAILABLE_END
+  #define __API_AVAILABLE_END(...)
+#endif
+
+#ifndef __API_DEPRECATED
+  #define __API_DEPRECATED(...)
+#endif
+
+#ifndef __API_DEPRECATED_BEGIN
+  #define __API_DEPRECATED_BEGIN(...)
+#endif
+
+#ifndef __API_DEPRECATED_END
+  #define __API_DEPRECATED_END(...)
+#endif
+
+#ifndef __API_DEPRECATED_WITH_REPLACEMENT
+  #define __API_DEPRECATED_WITH_REPLACEMENT(...)
+#endif
+
+#ifndef __API_DEPRECATED_WITH_REPLACEMENT_BEGIN
+  #define __API_DEPRECATED_WITH_REPLACEMENT_BEGIN(...)
+#endif
+
+#ifndef __API_DEPRECATED_WITH_REPLACEMENT_END
+  #define __API_DEPRECATED_WITH_REPLACEMENT_END(...)
+#endif
+
+#ifndef __API_UNAVAILABLE
+  #define __API_UNAVAILABLE(...)
+#endif
+
+#ifndef __API_UNAVAILABLE_BEGIN
+  #define __API_UNAVAILABLE_BEGIN(...)
+#endif
+
+#ifndef __API_UNAVAILABLE_END
+  #define __API_UNAVAILABLE_END(...)
 #endif
 
 /*
@@ -479,4 +532,5 @@
   #define __SPI_DEPRECATED_WITH_REPLACEMENT(...)
 #endif
 
-#endif /* __AVAILABILITY__ */
\ No newline at end of file
+#endif /* __AVAILABILITY__ */
+
